#!/usr/bin/env python3

# Check that each frequency list has a corresponding entry in the __meta__.tsv
# table and vice versa.

import os
import sys
import csv


def column(tsvfile, colname="id"):
    with open(tsvfile, newline="") as fh:
        tsv = csv.reader(fh, delimiter="\t")
        header = next(tsv)
        colnum = header.index(colname)
        return [row[colnum] for row in tsv]


def dir_matches_meta(root):
    meta = set(column(os.path.join(root, "__meta__.tsv")))
    dir = set([os.path.splitext(file)[0] for file in os.listdir(root)
               if file != "__meta__.tsv"])
    if meta == dir:
        print("The sets of text IDs of files under ``{0}`` and in the ``id`` "
              "column of ``{0}/__meta__.tsv`` are the same.".format(root))
        return True
    else:
        print("The sets of text IDs of files under ``{0}`` and in the ``id`` "
              "column of ``{0}/__meta__.tsv`` don't match.".format(root))
        print("Mismatches listed below:")
        print(meta.difference(dir).union(dir.difference(meta)))
        print("Fix the issue(s) and re-run the check.")
        return False


if __name__ == "__main__":
    success = dir_matches_meta("syn2015") and dir_matches_meta("syn_v3")
    sys.exit(0 if success else 1)
